Import-Module AU

function global:au_SearchReplace {
  @{
    ".\legal\verification.txt"      = @{
      "(?i)(32-Bit.+)\<.*\>"                       = "`${1}<$($Latest.URL32)>"
      "(?i)(64-Bit.+)\<.*\>"                       = "`${1}<$($Latest.URL64)>"
      "(?i)(checksum type:\s+).*"                  = "`${1}$($Latest.ChecksumType64)"
      "(?i)(checksum32:\s+).*"                     = "`${1}$($Latest.Checksum32)"
      "(?i)(checksum64:\s+).*"                     = "`${1}$($Latest.Checksum64)"
      "(?i)(downloaded.*release page\:?\s*)\<.*\>" = "`${1}<$($Latest.web_url)>"
    }
    ".\tools\chocolateyInstall.ps1" = @{
      "(?i)(^\s*FileFullPath\s*=\s*`"[$]toolsPath\\).*"   = "`${1}$($Latest.FileName32)`""
      "(?i)(^\s*FileFullPath64\s*=\s*`"[$]toolsPath\\).*" = "`${1}$($Latest.FileName64)`""
    }
  }
}

function global:au_BeforeUpdate {
  Get-RemoteFiles -Purge -NoSuffix
  
  $response = Invoke-WebRequest -Uri $Latest.ChecksumsUrl
  $rawCsv = ([System.Text.Encoding]::ASCII.GetString($response.Content)) -replace '  ',','

  $url32Hash = ConvertFrom-Csv -Header checksum,name $rawCsv | ? name -match 'windows_386.zip' | Select -First 1 -expand checksum
  $url64Hash = ConvertFrom-Csv -Header checksum,name $rawCsv | ? name -match 'windows_amd64.zip' | Select -First 1 -expand checksum

  if ($url32Hash -ne $Latest.Checksum32) {
    throw "File checksum of downloaded 32bit executable do not match expected upstream checksum"
  }
  if ($url64Hash -ne $Latest.Checksum64) {
    throw "File checksum of downloaded 64bit executable do not match expected upstream checksum"
  }
}

function global:au_GetLatest {
  $response = Invoke-WebRequest -Uri https://api.github.com/repos/restic/restic/releases/latest
  $release = ConvertFrom-Json $response.Content
  
  $version = $release.tag_name -replace '^v',''
  $url64   = $release.assets | ? name -match 'windows_amd64' | select -First 1 -expand browser_download_url
  $url32   = $release.assets | ? name -match 'windows_386' | select -First 1 -expand browser_download_url
  $checksumsUrl  = $release.assets | ? name -match 'SHA256SUMS$' | select -First 1 -expand browser_download_url

  return @{
    url32          = $url32
    url64          = $url64
    checksumType32 = 'SHA256'
    checksumType64 = 'SHA256'
    version        = $version
	ChecksumsUrl   = $checksumsUrl
    web_url        = $release.html_url
  }
}

update -ChecksumFor none -NoCheckChocoVersion
